<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Fotografie Pro
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function fotografie_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Always add a front-page class to the front page.
	if ( is_front_page() && ! is_home() ) {
		$classes[] = 'page-template-front-page';
	}

	// Adds a class of (full-width|box) to blogs.
	if ( 'fluid' === get_theme_mod( 'fotografie_layout_type' ) ) {
		$classes[] = 'fluid-layout';
	} else {
		$classes[] = 'boxed-layout';
	}

	// Adds a class with respect to layout selected.
	$layout  = fotografie_get_theme_layout();
	$sidebar = fotografie_get_sidebar_id();

	if ( 'no-sidebar-full-width' === $layout ) {
		$classes[] = 'no-sidebar full-width-layout';
	} elseif ( 'no-sidebar-full-content-width' === $layout ) {
		$classes[] = 'no-sidebar full-content-width-layout';
	} elseif ( 'left-sidebar' === $layout ) {
		if ( '' !== $sidebar ) {
			$classes[] = 'two-columns-layout content-right';
		}
	} elseif ( 'right-sidebar' === $layout ) {
		if ( '' !== $sidebar ) {
			$classes[] = 'two-columns-layout content-left';
		}
	} else {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'fotografie_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function fotografie_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'fotografie_pingback_header' );

if ( ! function_exists( 'fotografie_comment_form_fields' ) ) :
	/**
	 * Modify Comment Form Fields
	 *
	 * @uses comment_form_default_fields filter
	 * @since Fotografie Pro 1.0
	 */
	function fotografie_comment_form_fields( $fields ) {
		$disable_website = get_theme_mod( 'fotografie_website_field' );

		if ( isset( $fields['url'] ) && $disable_website ) {
			unset( $fields['url'] );
		}

		return $fields;
	}
endif; // fotografie_comment_form_fields.
add_filter( 'comment_form_default_fields', 'fotografie_comment_form_fields' );

if ( ! function_exists( 'fotografie_excerpt_length' ) ) :
	/**
	 * Sets the post excerpt length to n words.
	 *
	 * function tied to the excerpt_length filter hook.
	 * @uses filter excerpt_length
	 *
	 * @since Fotografie Pro 1.0
	 */
	function fotografie_excerpt_length( $length ) {
		if ( is_admin() ) {
			return $length;
		}

		// Getting data from Customizer Options.
		$length	= get_theme_mod( 'fotografie_excerpt_length', 45 );

		return absint( $length );
	}
endif; //fotografie_excerpt_length
add_filter( 'excerpt_length', 'fotografie_excerpt_length' );


if ( ! function_exists( 'fotografie_excerpt_more' ) ) :
	/**
	 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a option from customizer.
	 * @return string option from customizer prepended with an ellipsis.
	 */
	function fotografie_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}

		$more_tag_text = get_theme_mod( 'fotografie_excerpt_more_text',  esc_html__( 'Continue reading', 'fotografie-pro' ) );

		$link = sprintf( '<a href="%1$s" class="more-link"><span>%2$s</span></a>',
			esc_url( get_permalink( get_the_ID() ) ),
			/* translators: %s: Name of current post */
			wp_kses_data( $more_tag_text ) . '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>'
		);

		return ' &hellip; ' . $link;
	}
endif;
add_filter( 'excerpt_more', 'fotografie_excerpt_more' );


if ( ! function_exists( 'fotografie_custom_excerpt' ) ) :
	/**
	 * Adds Continue reading link to more tag excerpts.
	 *
	 * function tied to the get_the_excerpt filter hook.
	 *
	 * @since Fotografie Pro 1.0
	 */
	function fotografie_custom_excerpt( $output ) {

		if ( has_excerpt() && ! is_attachment() ) {
			$more_tag_text = get_theme_mod( 'fotografie_excerpt_more_text', esc_html__( 'Continue reading', 'fotografie-pro' ) );

			$link = sprintf( '<a href="%1$s" class="more-link"><span>%2$s</span></a>',
				esc_url( get_permalink( get_the_ID() ) ),
				/* translators: %s: Name of current post */
				wp_kses_data( $more_tag_text ) . '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>'
			);

			$output .= ' &hellip; ' . $link;
		}

		return $output;
	}
endif; // fotografie_custom_excerpt.
add_filter( 'get_the_excerpt', 'fotografie_custom_excerpt' );


if ( ! function_exists( 'fotografie_more_link' ) ) :
	/**
	 * Replacing Continue reading link to the_content more.
	 *
	 * function tied to the the_content_more_link filter hook.
	 *
	 * @since Fotografie Pro 1.0
	 */
	function fotografie_more_link( $more_link, $more_link_text ) {
		$more_tag_text = get_theme_mod( 'fotografie_excerpt_more_text', esc_html__( 'Continue reading', 'fotografie-pro' ) );

		return str_replace( $more_link_text, wp_kses_post( $more_tag_text ), $more_link );
	}
endif; // fotografie_more_link.
add_filter( 'the_content_more_link', 'fotografie_more_link', 10, 2 );

if ( ! function_exists( 'fotografie_rss_redirect' ) ) :
	/**
	 * Redirect WordPress Feeds To FeedBurner
	 *
	 * @action template_redirect
	 *
	 * @since Fotografie 1.0
	 */
	function fotografie_rss_redirect() {
		$feed_redirect 	= get_theme_mod( 'fotografie_feed_redirect' );

		if ( $feed_redirect ) {
			$url = 'Location: ' . $feed_redirect;

			if ( is_feed() && ! preg_match( '/feedburner|feedvalidator/i', $_SERVER['HTTP_USER_AGENT'] ) ) {
				header( esc_url( $url ) );
				header( 'HTTP/1.0 302 Temporary Redirect' );
			}
		}
	}
endif; //fotografie_rss_redirect
add_action( 'template_redirect', 'fotografie_rss_redirect' );


/**
 * Adds font family custom CSS
 */
function fotografie_get_font_family_css() {
	$font_family_options = fotografie_font_family_options();

	$fonts = fotografie_avaliable_fonts();

	$css = array();

	foreach ( $font_family_options as $key => $value ) {
		$option = get_theme_mod( $key );

		if ( $option !== $value['default'] && isset( $value['selector'] ) && isset( $fonts[ $option ]['label'] ) ) {
			$css[] = $value['selector'] . ' { font-family: ' . $fonts[ $option ]['label'] . '; }';
		}
	}

	$css = implode( PHP_EOL, $css );

	return $css;
}

/**
 * Remove first post from blog as it is already show via recent post template
 */
function fotografie_alter_home( $query ) {
	if ( $query->is_home() && $query->is_main_query() ) {
		$cats = get_theme_mod( 'fotografie_front_page_category' );

		if ( is_array( $cats ) && ! in_array( '0', $cats ) ) {
			$query->query_vars['category__in'] = $cats;
		}
	}
}
add_action( 'pre_get_posts', 'fotografie_alter_home' );

/**
 * Function to add Scroll Up icon
 */
function fotografie_scrollup() {
	$fotografie_disable_scrollup = get_theme_mod( 'fotografie_disable_scrollup' );

	if ( $fotografie_disable_scrollup ) {
		return;
	}

	echo '<a href="#masthead" id="scrollup" class="backtotop"><span class="screen-reader-text">' . esc_html__( 'Scroll Up', 'fotografie-pro' ) . '</span></a>' ;
}
add_action( 'wp_footer', 'fotografie_scrollup', 1 );

if ( ! function_exists( 'fotografie_content_nav' ) ) :
	/**
	 * Display navigation/pagination when applicable
	 *
	 * @since Fotografie Pro 1.1
	 */
	function fotografie_content_nav() {
		global $wp_query;

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$pagination_type = get_theme_mod( 'fotografie_pagination_type', 'default' );

		/**
		 * Check if navigation type is Jetpack Infinite Scroll and if it is enabled, else goto default pagination
		 * if it's active then disable pagination
		 */
		if ( ( 'infinite-scroll' === $pagination_type ) && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) {
			return false;
		}

		if ( 'numeric' === $pagination_type && function_exists( 'the_posts_pagination' ) ) {
			the_posts_pagination( array(
				'prev_text'          => esc_html__( 'Previous', 'fotografie-pro' ),
				'next_text'          => esc_html__( 'Next', 'fotografie-pro' ),
				'before_page_number' => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Page', 'fotografie-pro' ) . ' </span>',
			) );
		} else {
			the_posts_navigation();
		}
	}
endif; // fotografie_content_nav

/**
 * Check if a section is enabled or not based on the $value parameter
 * @param  string $value Value of the section that is to be checked
 * @return boolean return true if section is enabled otherwise false
 */
function fotografie_check_section( $value ) {
	global $wp_query;

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts');

	return ( 'entire-site' == $value  || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $value ) );
}

/**
 * Return the first image in a post. Works inside a loop.
 * @param [integer] $post_id [Post or page id]
 * @param [string/array] $size Image size. Either a string keyword (thumbnail, medium, large or full) or a 2-item array representing width and height in pixels, e.g. array(32,32).
 * @param [string/array] $attr Query string or array of attributes.
 * @return [string] image html
 *
 * @since Fotografie Pro 1.1
 */

function fotografie_get_first_image( $postID, $size, $attr ) {
	ob_start();

	ob_end_clean();

	$image 	= '';

	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_post_field('post_content', $postID ) , $matches);

	if( isset( $matches [1] [0] ) ) {
		//Get first image
		$first_img = $matches [1] [0];

		return '<img class="pngfix wp-post-image" src="'. esc_url( $first_img ) .'">';
	}

	return false;
}

if ( ! function_exists( 'fotografie_get_theme_layout' ) ) :
	function fotografie_get_theme_layout() {
		$layout = '';

		if ( is_page_template( 'templates/no-sidebar.php' ) ) {
			$layout = 'no-sidebar';
		} elseif ( is_page_template( 'templates/full-width-page.php' ) ) {
			$layout = 'no-sidebar-full-width';
		} elseif ( is_page_template( 'templates/full-content-width-page.php' ) ) {
			$layout = 'no-sidebar-full-content-width';
		} elseif ( is_page_template( 'templates/left-sidebar.php' ) ) {
			$layout = 'left-sidebar';
		} elseif ( is_page_template( 'templates/right-sidebar.php' ) ) {
			$layout = 'right-sidebar';
		} else {
			$layout = get_theme_mod( 'fotografie_default_layout', 'right-sidebar' );

			if ( class_exists( 'WooCommerce' ) && ( is_shop() || is_woocommerce() || is_cart() || is_checkout() ) ) {
				$layout = get_theme_mod( 'fotografie_woocommerce_layout', 'no-sidebar' );
			} elseif ( is_archive() || is_home() ) {
				return '';
			}
		}

		return $layout;
	}
endif;

function fotografie_get_sidebar_id() {
	$sidebar = '';

	$layout = fotografie_get_theme_layout();

	$sidebaroptions = '';

	if ( 'no-sidebar-full-content-width' === $layout || 'no-sidebar-full-width' === $layout || 'no-sidebar' === $layout ) {
		return $sidebar;
	}

	// WooCommerce Shop Page excluding Cart and checkout.
	if ( class_exists( 'WooCommerce' ) && is_woocommerce() ) {
		$shop_id        = get_option( 'woocommerce_shop_page_id' );
		$sidebaroptions = get_post_meta( $shop_id, 'fotografie-sidebar-options', true );
	} else {
		global $post, $wp_query;

		// Front page displays in Reading Settings.
		$page_on_front  = get_option( 'page_on_front' );
		$page_for_posts = get_option( 'page_for_posts' );

		// Get Page ID outside Loop.
		$page_id = $wp_query->get_queried_object_id();

		// Blog Page or Front Page setting in Reading Settings.
		if ( $page_id == $page_for_posts || $page_id == $page_on_front ) {
			$sidebaroptions = get_post_meta( $page_id, 'fotografie-sidebar-options', true );
		} elseif ( is_singular() ) {
			if ( is_attachment() ) {
				$parent 		= $post->post_parent;
				$sidebaroptions = get_post_meta( $parent, 'fotografie-sidebar-options', true );

			} else {
				$sidebaroptions = get_post_meta( $post->ID, 'fotografie-sidebar-options', true );
			}
		}
	}

	if ( is_active_sidebar( 'sidebar-6' ) && class_exists( 'WooCommerce' ) && ( is_woocommerce() || is_cart() || is_checkout() ) ) {
		$sidebar = 'sidebar-6'; // WooCommerce Sidebar.
	} elseif ( is_active_sidebar( 'sidebar-optional-one' ) && 'optional-sidebar-one' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-one';
	} elseif ( is_active_sidebar( 'sidebar-optional-two' ) && 'optional-sidebar-two' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-two';
	} elseif ( is_active_sidebar( 'sidebar-optional-three' ) && 'optional-sidebar-three' === $sidebaroptions ) {
		$sidebar = 'sidebar-optional-three';
	} elseif ( is_page() && is_active_sidebar( 'sidebar-optional-page' ) ) {
		$sidebar = 'sidebar-optional-page';
	} elseif ( is_single() && is_active_sidebar( 'sidebar-optional-post' ) ) {
		$sidebar = 'sidebar-optional-post';
	} elseif ( is_active_sidebar( 'sidebar-1' ) ) {
		$sidebar = 'sidebar-1'; // Primary Sidebar.
	}

	return $sidebar;
}

/**
 * Display social Menu
 */
function fotografie_social_menu() {
	if ( has_nav_menu( 'social-menu' ) ) :
		?>
		<nav class="social-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Social Links Menu', 'fotografie-pro' ); ?>">
			<?php
				wp_nav_menu( array(
					'theme_location' => 'social-menu',
					'link_before'    => '<span class="screen-reader-text">',
					'link_after'     => '</span>',
					'depth'          => 1,
				) );
			?>
		</nav><!-- .social-navigation -->
	<?php endif;
}


if ( ! function_exists( 'fotografie_truncate_phrase' ) ) :
	/**
	 * Return a phrase shortened in length to a maximum number of characters.
	 *
	 * Result will be truncated at the last white space in the original string. In this function the word separator is a
	 * single space. Other white space characters (like newlines and tabs) are ignored.
	 *
	 * If the first `$max_characters` of the string does not contain a space character, an empty string will be returned.
	 *
	 * @since NepalBuzz 1.0
	 *
	 * @param string $text            A string to be shortened.
	 * @param integer $max_characters The maximum number of characters to return.
	 *
	 * @return string Truncated string
	 */
	function fotografie_truncate_phrase( $text, $max_characters ) {

		$text = trim( $text );

		if ( mb_strlen( $text ) > $max_characters ) {
			//* Truncate $text to $max_characters + 1
			$text = mb_substr( $text, 0, $max_characters + 1 );

			//* Truncate to the last space in the truncated string
			$text = trim( mb_substr( $text, 0, mb_strrpos( $text, ' ' ) ) );
		}

		return $text;
	}
endif; //fotografie_truncate_phrase


if ( ! function_exists( 'fotografie_get_the_content_limit' ) ) :
	/**
	 * Return content stripped down and limited content.
	 *
	 * Strips out tags and shortcodes, limits the output to `$max_char` characters, and appends an ellipsis and more link to the end.
	 *
	 * @since NepalBuzz 1.0
	 *
	 * @param integer $max_characters The maximum number of characters to return.
	 * @param string  $more_link_text Optional. Text of the more link. Default is "(more...)".
	 * @param bool    $stripteaser    Optional. Strip teaser content before the more text. Default is false.
	 *
	 * @return string Limited content.
	 */
	function fotografie_get_the_content_limit( $max_characters, $more_link_text = '(more...)', $stripteaser = false ) {

		$content = get_the_content( '', $stripteaser );

		// Strip tags and shortcodes so the content truncation count is done correctly.
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'get_the_content_limit_allowedtags', '<script>,<style>' ) );

		// Remove inline styles / .
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		// Truncate $content to $max_char
		$content = fotografie_truncate_phrase( $content, $max_characters );

		// More link?
		if ( $more_link_text ) {
			$link   = apply_filters( 'get_the_content_more_link', sprintf( '<span class="more-button"><a href="%s" class="more-link">%s</a></span>', esc_url( get_permalink() ), $more_link_text ), $more_link_text );
			$output = sprintf( '<p>%s %s</p>', $content, $link );
		} else {
			$output = sprintf( '<p>%s</p>', $content );
			$link = '';
		}

		return apply_filters( 'fotografie_get_the_content_limit', $output, $content, $link, $max_characters );

	}
endif; //fotografie_get_the_content_limit

if ( ! function_exists( 'fotografie_content_image' ) ) :
	/**
	 * Template for Featured Image in Archive Content
	 *
	 * To override this in a child theme
	 * simply fabulous-fluid your own fotografie_content_image(), and that function will be used instead.
	 *
	 * @since Fotografie Pro 1.0
	 */
	function fotografie_content_image() {
		if ( has_post_thumbnail() && fotografie_jetpack_featured_image_display() && is_singular() ) {
			global $post, $wp_query;

			// Get Page ID outside Loop.
			$page_id = $wp_query->get_queried_object_id();

			if ( $post ) {
				if ( is_attachment() ) {
					$parent = $post->post_parent;

					$individual_featured_image = get_post_meta( $parent, 'fotografie-single-image', true );
				} else {
					$individual_featured_image = get_post_meta( $page_id, 'fotografie-single-image', true );
				}
			}

			if ( empty( $individual_featured_image ) ) {
				$individual_featured_image = 'default';
			}

			if ( 'disable' === $individual_featured_image ) {
				echo '<!-- Page/Post Single Image Disabled from metabox or No Image set in Post Thumbnail -->';
				return false;
			} else {
				$class = array();

				$image_size = 'post-thumbnail';

				if ( 'default' !== $individual_featured_image ) {
					$image_size = $individual_featured_image;
					$class[]    = 'from-metabox';
				} else {
					if ( 'disable' === get_theme_mod( 'fotografie_singular_image' ) ) {
						echo '<!-- Page/Post Single Image Disabled from theme options or No Image set in Post Thumbnail -->';
						return;
					}

					$layout = fotografie_get_theme_layout();

					if ( 'no-sidebar-full-width' === $layout ) {
						$image_size = 'fotografie-slider';
					}
				}

				$class[] = $individual_featured_image;
				?>
				<div class="post-thumbnail <?php echo esc_attr( implode( ' ', $class ) ); ?>">
					<?php the_post_thumbnail( $image_size ); ?>
				</div>
			<?php
			}
		} // End if().
	}
endif; // fotografie_content_image.

if ( ! function_exists( 'fotografie_enable_homepage_posts' ) ) :
	/**
	 * Determine Homepage Content disabled or not
	 * @return boolean
	 */
	function fotografie_enable_homepage_posts() {
	   if ( ! ( get_theme_mod( 'fotografie_disable_homepage_posts' ) && is_front_page() ) ) {
			return true;
		}
		return false;
	}

endif; // fotografie_enable_homepage_posts.

if ( ! function_exists( 'fotografie_header_media' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own fotografie_featured_pagepost_image(), and that function will be used instead.
	 *
	 * @since High Responsive 1.0
	 */
	function fotografie_header_media() {
		global $post, $wp_query;
		$enable = get_theme_mod( 'fotografie_header_media_option', 'homepage' );

		// Get Page ID outside Loop
		$page_id = absint( $wp_query->get_queried_object_id() );

		$page_for_posts = absint( get_option( 'page_for_posts' ) );

		// Check Enable/Disable header image in Page/Post Meta box
		if ( is_page() || is_single() ) {
			//Individual Page/Post Image Setting
			$individual_featured_image = get_post_meta( $post->ID, 'fotografie-header-image', true );

			if ( 'disable' === $individual_featured_image || ( 'default' === $individual_featured_image && 'disable' === $enable ) ) {
				echo '<!-- Page/Post Disable Header Image -->';
				return;
			} elseif ( 'enable' == $individual_featured_image && 'disable' === $enable ) {
				fotografie_featured_page_post_image();
			}
		}

		// Check Homepage
		if ( 'homepage' === $enable ) {
			if ( is_front_page() || ( is_home() && intval( $page_for_posts ) !== intval( $page_id ) ) ) {
				fotografie_featured_image();
			}
		}
		// Check Excluding Homepage
		if ( 'exclude-home' === $enable ) {
			if ( is_front_page() || ( is_home() && intval( $page_for_posts ) !== intval( $page_id ) ) ) {
				return false;
			} else {
				fotografie_featured_image();
			}
		} elseif ( 'exclude-home-page-post' === $enable ) {
			if ( is_front_page() || ( is_home() && intval( $page_for_posts ) !== intval( $page_id ) ) ) {
				return false;
			} elseif ( is_page() || is_single() ) {
				fotografie_featured_page_post_image();
			} else {
				fotografie_featured_image();
			}
		} elseif ( 'entire-site' === $enable ) {
			// Check Entire Site
			fotografie_featured_image();
		} elseif ( 'entire-site-page-post' === $enable ) {
			// Check Entire Site (Post/Page)
			if ( is_page() || is_single() || ( is_home() && $page_for_posts === $page_id ) ) {
				fotografie_featured_page_post_image();
			} else {
				fotografie_featured_image();
			}
		} elseif ( 'pages-posts' === $enable ) {
			// Check Page/Post
			if ( is_page() || is_single() ) {
				fotografie_featured_page_post_image();
			}
		}
	} // fotografie_header_media
endif;

if ( ! function_exists( 'fotografie_featured_image' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own fotografie_featured_image(), and that function will be used instead.
	 *
	 * @since Catch Base 1.0
	 */
	function fotografie_featured_image() {
		if ( has_custom_header() ) : ?>
			<div class="custom-header-media">
				<?php the_custom_header_markup(); ?>
			</div><!-- .custom-header-media -->
		<?php
		elseif ( is_post_type_archive( 'jetpack-portfolio' ) ) : ?>
			<?php
			$jetpack_portfolio_featured_image = get_option( 'jetpack_portfolio_featured_image' );
			if ( '' !== $jetpack_portfolio_featured_image ) : ?>
				<div class="custom-header-media">
					<?php echo wp_get_attachment_image( (int) $jetpack_portfolio_featured_image, 'fotografie-header-image' ); ?>
				</div><!-- .custom-header-media -->
			<?php
			endif;
		endif; // End featured/header image check.
	} // fotografie_featured_image
endif;

if ( ! function_exists( 'fotografie_featured_page_post_image' ) ) :
	/**
	 * Template for Featured Header Image from Post and Page
	 *
	 * To override this in a child theme
	 * simply create your own fotografie_featured_page_post_image(), and that function will be used instead.
	 *
	 * @since High Responsive 1.0
	 */
	function fotografie_featured_page_post_image() {
		if ( has_post_thumbnail() ) {
			global $post, $wp_query;

			// Get Page ID outside Loop.
			$page_id = $wp_query->get_queried_object_id();

			if ( $post ) {
				if ( is_attachment() ) {
					$parent = $post->post_parent;

					$individual_featured_image = get_post_meta( $parent, 'fotografie-header-image', true );
				} else {
					$individual_featured_image = get_post_meta( $page_id, 'fotografie-header-image', true );
				}
			}

			if ( empty( $individual_featured_image ) ) {
				$individual_featured_image = 'default';
			}

			if ( 'disable' === $individual_featured_image ) {
				echo '<!-- Header Image Disabled from Metabox -->';
				return false;
			} else { ?>
			<div class="custom-header-media">
				<img src="<?php the_post_thumbnail_url( 'fotografie-header-image' ); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" class="custom-header">
			</div><!-- .custom-header-media -->
			<?php
			}
		} else {
			fotografie_featured_image();
		}
	} // fotografie_featured_page_post_image
endif;
